package com.huimv.guowei.admin.service.impl;

import cn.hutool.core.date.DateUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huimv.guowei.admin.common.utils.Result;
import com.huimv.guowei.admin.common.utils.ResultCode;
import com.huimv.guowei.admin.entity.Farm;
import com.huimv.guowei.admin.entity.RawData;
import com.huimv.guowei.admin.mapper.RawDataMapper;
import com.huimv.guowei.admin.service.IRawDataService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.apache.poi.util.StringUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.*;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author author
 * @since 2023-06-25
 */
@Service
public class RawDataServiceImpl extends ServiceImpl<RawDataMapper, RawData> implements IRawDataService {
    @Override
    public Result listInfo(Map<String, String> paramsMap) {
        String deviceCode = paramsMap.get("deviceCode");
        String startDate = paramsMap.get("startDate");
        String endDate = paramsMap.get("endDate");
        String pageNum = paramsMap.get("pageNum");
        String pageSize = paramsMap.get("pageSize");

        QueryWrapper<RawData> wrapper = new QueryWrapper<>();
        if (StringUtils.isNotBlank(deviceCode)){
            wrapper.eq("device_code",deviceCode);
        }
        if (StringUtils.isNotBlank(startDate)){
            startDate += " 00:00:00";
            wrapper.ge("create_time", startDate);
        }
        if (StringUtils.isNotBlank(endDate)){
            endDate += " 23:59:59";
            wrapper.le("create_time", endDate);
        }
        wrapper.orderByDesc("id");
        Page<RawData> page = this.page(new Page<>(Integer.parseInt(pageNum), Integer.parseInt(pageSize)), wrapper);
        return new Result(ResultCode.SUCCESS, page);
    }

    @Override
    public Result listWeight(Map<String, String> paramsMap) {
        String id = paramsMap.get("id");
        String time = paramsMap.get("time");
        Integer value = Integer.valueOf(time);
        String startDate = paramsMap.get("startDate");
        String endDate = paramsMap.get("endDate");
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        List list = new ArrayList();
        RawData rawData = new RawData();
        if (StringUtils.isNotBlank(id)){
            rawData = this.getById(id);
        }
        if (StringUtils.isNotBlank(startDate) && StringUtils.isNotBlank(endDate)){
            String deviceCode = rawData.getDeviceCode();
            QueryWrapper<RawData> wrapper = new QueryWrapper<>();
            wrapper.eq("device_code",deviceCode);
            startDate += " 00:00:00";
            endDate += " 23:59:59";
            wrapper.between("create_time",startDate,endDate);
            wrapper.orderByAsc("id");
            List<RawData> rawDataList = this.list(wrapper);
            for (RawData data : rawDataList) {
                String weightDate = data.getData();
                Date endTime = rawData.getCreateTime();
                String[] s = weightDate.split(" ");
                long timestamp = endTime.getTime() / 1000;
                for (int i = 0; i < 60; i++) {
                    long l = timestamp - ((60 - i) * value); // 修正此行
                    Date thenTime = new Date(l * 1000); // 将秒转换为毫秒
                    String str1 = s[i * 2 + 11] + s[i * 2 + 10];
                    BigDecimal weight = new BigDecimal(Integer.parseInt(str1, 16));
                    Map weightMap = new HashMap();
                    weightMap.put("time", sdf.format(thenTime));
                    weightMap.put("weight",weight);
                    list.add(weightMap);
                }
            }
        }else {
            Date endTime = rawData.getCreateTime();
            String data = rawData.getData();
            String[] s = data.split(" ");
            long timestamp = endTime.getTime() / 1000;
            for (int i = 0; i < 60; i++) {
                long l = timestamp - ((60 - i) * value); // 修正此行
                Date thenTime = new Date(l * 1000); // 将秒转换为毫秒
                String str1 = s[i * 2 + 11] + s[i * 2 + 10];
                BigDecimal weight = new BigDecimal(Integer.parseInt(str1, 16));
                Map weightMap = new HashMap();
                weightMap.put("time", sdf.format(thenTime));
                weightMap.put("weight",weight);
                list.add(weightMap);
            }
        }
        return new Result(ResultCode.SUCCESS,list);
    }
}
